package cn.com.infosec.asn1.tsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.IOException;
import java.util.Enumeration;

public class TSTInfo extends ASN1Encodable {
   DERInteger version;
   DERObjectIdentifier tsaPolicyId;
   MessageImprint messageImprint;
   DERInteger serialNumber;
   DERGeneralizedTime genTime;
   Accuracy accuracy;
   DERBoolean ordering;
   DERInteger nonce;
   GeneralName tsa;
   X509Extensions extensions;

   public static TSTInfo getInstance(Object o) {
      if (o != null && !(o instanceof TSTInfo)) {
         if (o instanceof ASN1Sequence) {
            return new TSTInfo((ASN1Sequence)o);
         } else if (o instanceof ASN1OctetString) {
            try {
               return getInstance((new ASN1InputStream(((ASN1OctetString)o).getOctets())).readObject());
            } catch (IOException var1) {
               throw new IllegalArgumentException("Bad object format in 'TSTInfo' factory.");
            }
         } else {
            throw new IllegalArgumentException("Unknown object in 'TSTInfo' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (TSTInfo)o;
      }
   }

   public TSTInfo(ASN1Sequence seq) {
      Enumeration seq1;
      this.version = DERInteger.getInstance((seq1 = seq.getObjects()).nextElement());
      this.tsaPolicyId = DERObjectIdentifier.getInstance(seq1.nextElement());
      this.messageImprint = MessageImprint.getInstance(seq1.nextElement());
      this.serialNumber = DERInteger.getInstance(seq1.nextElement());
      this.genTime = DERGeneralizedTime.getInstance(seq1.nextElement());
      this.ordering = new DERBoolean(false);

      while(seq1.hasMoreElements()) {
         DERObject var2;
         if ((var2 = (DERObject)seq1.nextElement()) instanceof ASN1TaggedObject) {
            int var3;
            DERTaggedObject var5;
            if ((var3 = (var5 = (DERTaggedObject)var2).getTagNo()) != 0) {
               if (var3 != 1) {
                  throw new IllegalArgumentException("Unknown tag value " + var5.getTagNo());
               }

               this.extensions = X509Extensions.getInstance(var5, false);
            } else {
               this.tsa = GeneralName.getInstance(var5, true);
            }
         } else if (var2 instanceof DERSequence) {
            this.accuracy = Accuracy.getInstance(var2);
         } else if (var2 instanceof DERBoolean) {
            this.ordering = DERBoolean.getInstance(var2);
         } else if (var2 instanceof DERInteger) {
            this.nonce = DERInteger.getInstance(var2);
         }
      }

   }

   public TSTInfo(DERObjectIdentifier tsaPolicyId, MessageImprint messageImprint, DERInteger serialNumber, DERGeneralizedTime genTime, Accuracy accuracy, DERBoolean ordering, DERInteger nonce, GeneralName tsa, X509Extensions extensions) {
      TSTInfo var10000 = this;
      TSTInfo var10001 = this;
      TSTInfo var10002 = this;
      TSTInfo var10003 = this;
      TSTInfo var10004 = this;
      TSTInfo var10005 = this;
      TSTInfo var10006 = this;
      TSTInfo var10007 = this;
      TSTInfo var10008 = this;
      TSTInfo var10009 = this;
      super();
      DERInteger var10;
      var10 = new DERInteger.<init>(1);
      var10009.version = var10;
      var10008.tsaPolicyId = tsaPolicyId;
      var10007.messageImprint = messageImprint;
      var10006.serialNumber = serialNumber;
      var10005.genTime = genTime;
      var10004.accuracy = accuracy;
      var10003.ordering = ordering;
      var10002.nonce = nonce;
      var10001.tsa = tsa;
      var10000.extensions = extensions;
   }

   public MessageImprint getMessageImprint() {
      return this.messageImprint;
   }

   public DERObjectIdentifier getPolicy() {
      return this.tsaPolicyId;
   }

   public DERInteger getSerialNumber() {
      return this.serialNumber;
   }

   public Accuracy getAccuracy() {
      return this.accuracy;
   }

   public DERGeneralizedTime getGenTime() {
      return this.genTime;
   }

   public DERBoolean getOrdering() {
      return this.ordering;
   }

   public DERInteger getNonce() {
      return this.nonce;
   }

   public GeneralName getTsa() {
      return this.tsa;
   }

   public X509Extensions getExtensions() {
      return this.extensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.tsaPolicyId);
      var1.add(this.messageImprint);
      var1.add(this.serialNumber);
      var10001.add(this.genTime);
      Accuracy var2;
      if ((var2 = this.accuracy) != null) {
         var1.add(var2);
      }

      DERBoolean var5;
      if ((var5 = this.ordering) != null && var5.isTrue()) {
         var1.add(this.ordering);
      }

      DERInteger var6;
      if ((var6 = this.nonce) != null) {
         var1.add(var6);
      }

      GeneralName var7;
      if ((var7 = this.tsa) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(true, 0, var7);
         var1.add(var3);
      }

      X509Extensions var4;
      if ((var4 = this.extensions) != null) {
         DERTaggedObject var8;
         var8 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var8);
      }

      return new DERSequence(var1);
   }
}
